@@ -7,7 +7,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-06-19'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.026'; # VERSION
+our $VERSION = '1.027'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -48,13 +48,13 @@ _
             summary => 'Specify how the output CSV is to be filled',
             schema => ['str*', in=>[
                 'left_to_right_then_top_to_bottom',
-                #'right_to_left_then_top_to_bottom',
-                #'left_to_right_then_bottom_to_top',
-                #'right_to_left_then_bottom_to_top',
-                #'top_to_bottom_then_left_to_right',
-                #'top_to_bottom_then_right_to_left',
-                #'bottom_to_top_then_left_to_right',
-                #'bottom_to_top_then_right_to_left',
+                'right_to_left_then_top_to_bottom',
+                'left_to_right_then_bottom_to_top',
+                'right_to_left_then_bottom_to_top',
+                'top_to_bottom_then_left_to_right',
+                'top_to_bottom_then_right_to_left',
+                'bottom_to_top_then_left_to_right',
+                'bottom_to_top_then_right_to_left',
             ]],
             default => 'left_to_right_then_top_to_bottom',
             tags => ['category:layout'],
@@ -227,7 +227,7 @@ App::CSVUtils::csv_fill_cells - Create a CSV and fill its cells from supplied va
 
 =head1 VERSION
 
-This document describes version 1.026 of App::CSVUtils::csv_fill_cells (from Perl distribution App-CSVUtils), released on 2023-06-19.
+This document describes version 1.027 of App::CSVUtils::csv_fill_cells (from Perl distribution App-CSVUtils), released on 2023-06-19.
 
 =head1 FUNCTIONS
 
